@@ -1,5 +1,5 @@
 /* main.h - Main header file for redir. */
-/* $Id: main.h,v 2.0 1998/08/10 06:55:59 caleishm Exp caleishm $  */
+/* $Id: main.h,v 2.2 1999/01/07 05:39:10 caleishm Exp caleishm $  */
 /* Chris Leishman, Trevor Cohn.  Ormond College student IT department, 1998.*/
 
 #ifndef MAIN_H
@@ -10,23 +10,36 @@
 #define EOS     (char) NULL
 #define EOLN    '\n'
 
+#ifndef NOUSE_REGEX
+#include <regex.h>
+#endif
 
-enum Type {CONTAINS, HOSTCONTAINS, PATHCONTAINS, 
-           EXEMPT, HOSTEXEMPT, PATHEXEMPT};
+
+enum Type {CONTAINS, HOSTCONTAINS, PATHCONTAINS, SOURCECONTAINS,
+           EXEMPT, HOSTEXEMPT, PATHEXEMPT, SOURCEEXEMPT};
 
 typedef struct sstr_list {
 	char *data;
-#ifndef NOSAVESKIP
+#ifndef NOUSE_REGEX
+	regex_t *regc;
+#elif !defined NOSAVESKIP
 	int *skip;
 #endif
 	struct sstr_list *next;
 } str_list;
 
+typedef struct _redir_list {
+	int type;
+	char *data;
+	struct _redir_list *next;
+} redir_list;
+
 typedef struct iitem {
 	int type;
 	int random;
+	int numredir;
 	str_list *keys;
-	str_list *redirect;
+	redir_list *redirect;
 	char *logfile;
 	struct iitem *subs;
 	struct iitem *next;
