@@ -6,6 +6,6 @@
 #define REDIR_H
 
 
-extern void redirect(item *, char *);
+extern void redirect(item *, char *, char *);
 
 #endif
